@@ -28,12 +28,15 @@ A simple class that encapsulates information about Amazon sites.
 
 =cut
 
+use strict;
+use warnings;
+
 use Feature::Compat::Class;
 
 use feature 'signatures';
 no warnings 'experimental::signatures';
 
-our $VERSION = '0.1.2';
+our $VERSION = '0.1.3';
 
 class Amazon::Sites {
   use Amazon::Site;
